# NOT RUN {
## Set up the data.
data(breast.17) # the breast cancer dataset
breast.data <- as.matrix(breast.17) # put data in matrix object
## Generate at least two chains, from models which are the same except
## for different \eqn{M} values.
set.seed(1) # initialize the seed at 1
breast.c1 <- dirichlet.c(breast.data, ncycles=4000, M=5)
breast.c2 <- dirichlet.c(breast.data,ncycles=4000, M=1000)
## Create list object.
breast.c1c2 <- list("5"=breast.c1$chain, "1000"= breast.c2$chain)
## Decide on some number of initial runs to omit from the analysis.
describe.post(breast.c1c2, burnin=100)
# }
Run the code above in your browser using DataLab